@@ -1004,7 +1004,7 @@ static void btstack_crypto_handle_random_data(const uint8_t * data, uint16_t len
             break;
 #ifdef ENABLE_ECC_P256
         case BTSTACK_CRYPTO_ECC_P256_GENERATE_KEY:
-            btstack_assert((btstack_crypto_ecc_p256_random_len + 8) <= 64u);
+            btstack_assert((btstack_crypto_ecc_p256_random_len + 8) <= 64);
             (void)memcpy(&btstack_crypto_ecc_p256_random[btstack_crypto_ecc_p256_random_len], data, 8);
             btstack_crypto_ecc_p256_random_len += 8u;
             if (btstack_crypto_ecc_p256_random_len >= 64u) {
@@ -1261,7 +1261,8 @@ int btstack_crypto_ecc_p256_validate_public_key(const uint8_t * public_key){
     // validate public key using micro-ecc
     int err = 0;
 
-#ifdef USE_MICRO_ECC_P256
+#if defined (USE_MICRO_ECC_P256)
+
 #if uECC_SUPPORTS_secp256r1
     // standard version
     err = uECC_valid_public_key(public_key, uECC_secp256r1()) == 0;
@@ -1269,9 +1270,8 @@ int btstack_crypto_ecc_p256_validate_public_key(const uint8_t * public_key){
     // static version
     err = uECC_valid_public_key(public_key) == 0;
 #endif
-#endif
 
-#ifdef USE_MBEDTLS_ECC_P256
+#elif defined(USE_MBEDTLS_ECC_P256)
     mbedtls_ecp_point Q;
     mbedtls_ecp_point_init( &Q );
     mbedtls_mpi_read_binary(&Q.X, &public_key[0], 32);
@@ -1279,6 +1279,12 @@ int btstack_crypto_ecc_p256_validate_public_key(const uint8_t * public_key){
     mbedtls_mpi_lset(&Q.Z, 1);
     err = mbedtls_ecp_check_pubkey(&mbedtls_ec_group, &Q);
     mbedtls_ecp_point_free( & Q);
+#else
+
+    UNUSED(public_key);
+    err = 1;
+    log_error("No elliptic curve library available");
+
 #endif
 
     if (err != 0){
@@ -1346,7 +1352,7 @@ void btstack_crypto_ccm_decrypt_block(btstack_crypto_ccm_t * request, uint16_t l
 }
 
 
-static void btstack_crypto_state_reset() {
+static void btstack_crypto_state_reset(void) {
 #ifndef USE_BTSTACK_AES128
     btstack_crypto_cmac_state = CMAC_IDLE;
 #endif
