@@ -20,8 +20,8 @@
  * THIS SOFTWARE IS PROVIDED BY BLUEKITCHEN GMBH AND CONTRIBUTORS
  * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
  * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
- * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL MATTHIAS
- * RINGWALD OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
+ * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL BLUEKITCHEN
+ * GMBH OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
  * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
  * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
  * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
@@ -108,49 +108,52 @@ const mesh_access_message_t mesh_foundation_health_attention_status = {
 static mesh_pdu_t * health_period_status(mesh_model_t * mesh_model){
     mesh_health_state_t * state = (mesh_health_state_t *) mesh_model->model_data;
     // setup message
-    mesh_network_pdu_t * transport_pdu = mesh_access_setup_unsegmented_message(&mesh_foundation_health_period_status, state->fast_period_divisor);
-    return (mesh_pdu_t *) transport_pdu;
+    mesh_upper_transport_pdu_t * message_pdu = mesh_access_setup_message(&mesh_foundation_health_period_status, state->fast_period_divisor);
+    return (mesh_pdu_t *) message_pdu;
 }
 
 static mesh_pdu_t * health_attention_status(void){
     // setup message
-    mesh_network_pdu_t * transport_pdu = mesh_access_setup_unsegmented_message(&mesh_foundation_health_attention_status, mesh_attention_timer_get());
-    return (mesh_pdu_t *) transport_pdu;
+    mesh_upper_transport_pdu_t * message_pdu = mesh_access_setup_message(&mesh_foundation_health_attention_status, mesh_attention_timer_get());
+    return (mesh_pdu_t *) message_pdu;
 }
 
 // report fault status - used for both current as well as registered faults, see registered_faults param
 static mesh_pdu_t * health_fault_status(mesh_model_t * mesh_model, uint32_t opcode, uint16_t company_id, bool registered_faults){
-    mesh_network_pdu_t * transport_pdu = mesh_access_network_init(opcode);
-    if (!transport_pdu) return NULL;
+    mesh_upper_transport_builder_t builder;
+    mesh_access_message_init(&builder, opcode);
 
     mesh_health_fault_t * fault = mesh_health_server_fault_for_company_id(mesh_model, company_id);
     if (fault == NULL){
         // no fault state with company_id found
-        mesh_access_network_add_uint8(transport_pdu, 0);
-        mesh_access_network_add_uint16(transport_pdu, company_id);
+        mesh_access_message_add_uint8(&builder, 0);
+        mesh_access_message_add_uint16(&builder, company_id);
     } else {
-        mesh_access_network_add_uint8(transport_pdu, fault->test_id);
-        mesh_access_network_add_uint16(transport_pdu, fault->company_id);
+        mesh_access_message_add_uint8(&builder, fault->test_id);
+        mesh_access_message_add_uint16(&builder, fault->company_id);
         int i;
         if (registered_faults){
             for (i = 0; i < fault->num_registered_faults; i++){
-                 mesh_access_network_add_uint8(transport_pdu, fault->registered_faults[i]);
+                 mesh_access_message_add_uint8(&builder, fault->registered_faults[i]);
             }
         }  else {
             for (i = 0; i < fault->num_current_faults; i++){
-                 mesh_access_network_add_uint8(transport_pdu, fault->current_faults[i]);
+                 mesh_access_message_add_uint8(&builder, fault->current_faults[i]);
             }
         }
     }
-    return (mesh_pdu_t *) transport_pdu;
+
+    mesh_upper_transport_pdu_t * upper_pdu = mesh_access_message_finalize(&builder);
+
+    return (mesh_pdu_t *) upper_pdu;
 }
 
 static void health_fault_get_handler(mesh_model_t *mesh_model, mesh_pdu_t * pdu){
     mesh_access_parser_state_t parser;
     mesh_access_parser_init(&parser, (mesh_pdu_t*) pdu);
-    uint16_t company_id = mesh_access_parser_get_u16(&parser);
+    uint16_t company_id = mesh_access_parser_get_uint16(&parser);
 
-    mesh_transport_pdu_t * transport_pdu = (mesh_transport_pdu_t *) health_fault_status(mesh_model, MESH_FOUNDATION_OPERATION_HEALTH_FAULT_STATUS, company_id, true);
+    mesh_upper_transport_pdu_t * transport_pdu = (mesh_upper_transport_pdu_t *) health_fault_status(mesh_model, MESH_FOUNDATION_OPERATION_HEALTH_FAULT_STATUS, company_id, true);
     if (!transport_pdu) return;
     health_server_send_message(mesh_access_get_element_address(mesh_model), mesh_pdu_src(pdu), mesh_pdu_netkey_index(pdu), mesh_pdu_appkey_index(pdu),(mesh_pdu_t *) transport_pdu);
     mesh_access_message_processed(pdu);
@@ -159,7 +162,7 @@ static void health_fault_get_handler(mesh_model_t *mesh_model, mesh_pdu_t * pdu)
 static uint16_t process_message_fault_clear(mesh_model_t *mesh_model, mesh_pdu_t * pdu){
     mesh_access_parser_state_t parser;
     mesh_access_parser_init(&parser, (mesh_pdu_t*) pdu);
-    uint16_t company_id = mesh_access_parser_get_u16(&parser);
+    uint16_t company_id = mesh_access_parser_get_uint16(&parser);
 
     mesh_health_fault_t * fault = mesh_health_server_fault_for_company_id(mesh_model, company_id);
     if (fault != NULL){
@@ -172,7 +175,7 @@ static uint16_t process_message_fault_clear(mesh_model_t *mesh_model, mesh_pdu_t
 static void health_fault_clear_handler(mesh_model_t * mesh_model, mesh_pdu_t * pdu){
     uint16_t company_id = process_message_fault_clear(mesh_model, pdu);
 
-    mesh_transport_pdu_t * transport_pdu = (mesh_transport_pdu_t *) health_fault_status(mesh_model, MESH_FOUNDATION_OPERATION_HEALTH_FAULT_STATUS, company_id, true);
+    mesh_upper_transport_pdu_t * transport_pdu = (mesh_upper_transport_pdu_t *) health_fault_status(mesh_model, MESH_FOUNDATION_OPERATION_HEALTH_FAULT_STATUS, company_id, true);
     if (!transport_pdu) return;
     health_server_send_message(mesh_access_get_element_address(mesh_model), mesh_pdu_src(pdu), mesh_pdu_netkey_index(pdu), mesh_pdu_appkey_index(pdu),(mesh_pdu_t *) transport_pdu);
     mesh_access_message_processed(pdu);
@@ -187,8 +190,8 @@ static void health_fault_clear_unacknowledged_handler(mesh_model_t *mesh_model,
 static void health_fault_test_process_message(mesh_model_t *mesh_model, mesh_pdu_t * pdu, bool acknowledged){
     mesh_access_parser_state_t parser;
     mesh_access_parser_init(&parser, (mesh_pdu_t*) pdu);
-    uint8_t  test_id    = mesh_access_parser_get_u8(&parser);
-    uint16_t company_id = mesh_access_parser_get_u16(&parser);
+    uint8_t  test_id    = mesh_access_parser_get_uint8(&parser);
+    uint16_t company_id = mesh_access_parser_get_uint16(&parser);
     
     uint16_t dest = mesh_pdu_src(pdu);
     uint16_t netkey_index = mesh_pdu_netkey_index(pdu);
@@ -240,7 +243,7 @@ static void health_fault_test_unacknowledged_handler(mesh_model_t * mesh_model,
 }
 
 static void health_period_get_handler(mesh_model_t *mesh_model, mesh_pdu_t * pdu){
-    mesh_transport_pdu_t * transport_pdu = (mesh_transport_pdu_t *) health_period_status(mesh_model);
+    mesh_upper_transport_pdu_t * transport_pdu = (mesh_upper_transport_pdu_t *) health_period_status(mesh_model);
     if (!transport_pdu) return;
     health_server_send_message(mesh_access_get_element_address(mesh_model), mesh_pdu_src(pdu), mesh_pdu_netkey_index(pdu), mesh_pdu_appkey_index(pdu),(mesh_pdu_t *) transport_pdu);
     mesh_access_message_processed(pdu);
@@ -249,7 +252,7 @@ static void health_period_get_handler(mesh_model_t *mesh_model, mesh_pdu_t * pdu
 static void process_message_period_set(mesh_model_t *mesh_model, mesh_pdu_t * pdu){
     mesh_access_parser_state_t parser;
     mesh_access_parser_init(&parser, (mesh_pdu_t*) pdu);
-    uint8_t fast_period_divisor = mesh_access_parser_get_u8(&parser);
+    uint8_t fast_period_divisor = mesh_access_parser_get_uint8(&parser);
 
     mesh_health_state_t * state = (mesh_health_state_t *) mesh_model->model_data;
     state->fast_period_divisor = fast_period_divisor;
@@ -260,7 +263,7 @@ static void process_message_period_set(mesh_model_t *mesh_model, mesh_pdu_t * pd
 static void health_period_set_handler(mesh_model_t *mesh_model, mesh_pdu_t * pdu){
     process_message_period_set(mesh_model, pdu);
     
-    mesh_transport_pdu_t * transport_pdu = (mesh_transport_pdu_t *) health_period_status(mesh_model);
+    mesh_upper_transport_pdu_t * transport_pdu = (mesh_upper_transport_pdu_t *) health_period_status(mesh_model);
     if (!transport_pdu) return;
     health_server_send_message(mesh_access_get_element_address(mesh_model), mesh_pdu_src(pdu), mesh_pdu_netkey_index(pdu), mesh_pdu_appkey_index(pdu),(mesh_pdu_t *) transport_pdu);
     mesh_access_message_processed(pdu);
@@ -272,7 +275,7 @@ static void health_period_set_unacknowledged_handler(mesh_model_t *mesh_model, m
 }
 
 static void health_attention_get_handler(mesh_model_t *mesh_model, mesh_pdu_t * pdu){
-    mesh_transport_pdu_t * transport_pdu = (mesh_transport_pdu_t *) health_attention_status();
+    mesh_upper_transport_pdu_t * transport_pdu = (mesh_upper_transport_pdu_t *) health_attention_status();
     if (!transport_pdu) return;
     health_server_send_message(mesh_access_get_element_address(mesh_model), mesh_pdu_src(pdu), mesh_pdu_netkey_index(pdu), mesh_pdu_appkey_index(pdu),(mesh_pdu_t *) transport_pdu);
     mesh_access_message_processed(pdu);
@@ -281,7 +284,7 @@ static void health_attention_get_handler(mesh_model_t *mesh_model, mesh_pdu_t *
 static void process_message_attention_set(mesh_model_t *mesh_model, mesh_pdu_t * pdu){
     mesh_access_parser_state_t parser;
     mesh_access_parser_init(&parser, (mesh_pdu_t*) pdu);
-    uint8_t timer_s = mesh_access_parser_get_u8(&parser);
+    uint8_t timer_s = mesh_access_parser_get_uint8(&parser);
     mesh_attention_timer_set(timer_s);
     
     if (mesh_model->model_packet_handler == NULL) return;
@@ -302,7 +305,7 @@ static void process_message_attention_set(mesh_model_t *mesh_model, mesh_pdu_t *
 static void health_attention_set_handler(mesh_model_t *mesh_model, mesh_pdu_t * pdu){
     process_message_attention_set(mesh_model, pdu);
     
-    mesh_transport_pdu_t * transport_pdu = (mesh_transport_pdu_t *) health_attention_status();
+    mesh_upper_transport_pdu_t * transport_pdu = (mesh_upper_transport_pdu_t *) health_attention_status();
     if (!transport_pdu) return;
     health_server_send_message(mesh_access_get_element_address(mesh_model), mesh_pdu_src(pdu), mesh_pdu_netkey_index(pdu), mesh_pdu_appkey_index(pdu),(mesh_pdu_t *) transport_pdu);
     mesh_access_message_processed(pdu);
@@ -434,7 +437,7 @@ void mesh_health_server_report_test_done(uint16_t dest, uint16_t netkey_index, u
 
     // response for acknowledged health fault test
     if (acknowledged){
-        mesh_transport_pdu_t * transport_pdu = (mesh_transport_pdu_t *) health_fault_status(mesh_model, MESH_FOUNDATION_OPERATION_HEALTH_FAULT_STATUS, company_id, company_id);
+        mesh_upper_transport_pdu_t * transport_pdu = (mesh_upper_transport_pdu_t *) health_fault_status(mesh_model, MESH_FOUNDATION_OPERATION_HEALTH_FAULT_STATUS, company_id, company_id);
         if (!transport_pdu) return;
         health_server_send_message(mesh_node_get_primary_element_address(), dest, netkey_index, appkey_index, (mesh_pdu_t *) transport_pdu);
     }
