@@ -2,24 +2,23 @@
 // btstack_config.h for most tests
 //
 
-#ifndef __BTSTACK_CONFIG
-#define __BTSTACK_CONFIG
+#ifndef BTSTACK_CONFIG_H
+#define BTSTACK_CONFIG_H
 
 // Port related features
-#define HAVE_MALLOC
-#define HAVE_POSIX_TIME
-#define HAVE_POSIX_FILE_IO
 #define HAVE_BTSTACK_STDIN
-#define HAVE_ASSERT
+#define HAVE_MALLOC
+#define HAVE_POSIX_FILE_IO
+#define HAVE_POSIX_TIME
 
 // BTstack features that can be enabled
 #define ENABLE_BLE
-#define ENABLE_LE_PERIPHERAL
 #define ENABLE_LE_CENTRAL
-// #define ENABLE_LOG_DEBUG
+#define ENABLE_LE_PERIPHERAL
 #define ENABLE_LOG_ERROR
-#define ENABLE_LOG_INFO 
+#define ENABLE_LOG_INFO
 #define ENABLE_MICRO_ECC_P256
+#define ENABLE_PRINTF_HEXDUMP
 
 // Mesh Config
 #define ENABLE_MESH_ADV_BEARER
@@ -37,9 +36,9 @@
 #define HCI_INCOMING_PRE_BUFFER_SIZE 4
 
 #define MAX_NR_LE_DEVICE_DB_ENTRIES    4
+#define MAX_NR_MESH_SUBNETS            2
 #define MAX_NR_MESH_TRANSPORT_KEYS    16
 #define MAX_NR_MESH_VIRTUAL_ADDRESSES 16
-#define MAX_NR_MESH_SUBNETS            2
 
 // allow for one NetKey update
 #define MAX_NR_MESH_NETWORK_KEYS      (MAX_NR_MESH_SUBNETS+1)
