@@ -1,5 +1,5 @@
 /***********************************************************************************************************************
- * Copyright [2020-2021] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
+ * Copyright [2020-2023] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
  *
  * This software and documentation are supplied by Renesas Electronics America Inc. and may only be used with products
  * of Renesas Electronics Corp. and its affiliates ("Renesas").  No other uses are authorized.  Renesas products are
@@ -271,6 +271,13 @@ void usb_hstd_status_start (usb_utr_t * ptr)
         /* NoData Control */
         case USB_SETUPNDC:
         {
+ #if defined(USB_CFG_HUVC_USE)
+            if ((USB_SET_INTERFACE | USB_HOST_TO_DEV | USB_STANDARD | USB_INTERFACE) == hw_usb_read_usbreq(ptr->ip))
+            {
+                usb_cpu_delay_xms((uint16_t) 50);
+            }
+ #endif
+
             /* Control Read Status */
             usb_hstd_ctrl_read_start(ptr, (uint32_t) 0, (uint8_t *) &buf1);
 
@@ -319,14 +326,14 @@ void usb_hstd_ctrl_end (usb_utr_t * ptr, uint16_t status)
     {
         hw_usb_set_mbw(ptr, USB_CUSE, USB1_CFIFO_MBW);
 
- #if defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5)
+ #if defined(USB_HIGH_SPEED_MODULE)
 
         /* CSCLR=1, SUREQ=1, SQCLR=1, PID=NAK */
         hw_usb_hwrite_dcpctr(ptr, (uint16_t) ((USB_CSCLR | USB_SUREQCLR) | USB_SQCLR));
- #else                                 /* defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5) */
+ #else                                 /* defined (USB_HIGH_SPEED_MODULE) */
         /* SUREQ=1, SQCLR=1, PID=NAK */
         hw_usb_hwrite_dcpctr(ptr, (uint16_t) (USB_SUREQCLR | USB_SQCLR));
- #endif /* defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5) */
+ #endif /* defined (USB_HIGH_SPEED_MODULE) */
     }
     else
     {
@@ -364,17 +371,21 @@ void usb_hstd_ctrl_end (usb_utr_t * ptr, uint16_t status)
         }
     }
 
- #if (BSP_CFG_RTOS == 2)
+ #if (BSP_CFG_RTOS == 0)
+    g_p_usb_hstd_pipe[ptr->ip][USB_PIPE0] = (usb_utr_t *) USB_NULL;
+ #else                                      /* (BSP_CFG_RTOS == 0) */
+  #if (BSP_CFG_RTOS == 1)
+    USB_REL_BLK(1, g_p_usb_hstd_pipe[ptr->ip][USB_PIPE0]);
+  #elif (BSP_CFG_RTOS == 2)                 /* #if (BSP_CFG_RTOS == 1) */
     vPortFree(g_p_usb_hstd_pipe[ptr->ip][USB_PIPE0]);
+  #endif                                    /* #if (BSP_CFG_RTOS == 1) */
     g_p_usb_hstd_pipe[ptr->ip][USB_PIPE0] = (usb_utr_t *) USB_NULL;
     usb_cstd_pipe0_msg_re_forward(ptr->ip); /* Get PIPE0 Transfer wait que and Message send to HCD */
- #else  /* #if (BSP_CFG_RTOS == 2) */
-    g_p_usb_hstd_pipe[ptr->ip][USB_PIPE0] = (usb_utr_t *) USB_NULL;
- #endif /* #if (BSP_CFG_RTOS == 2) */
+ #endif                                     /* #if (BSP_CFG_RTOS == 0) */
 
  #if USB_CFG_COMPLIANCE == USB_CFG_ENABLE
     hw_usb_clear_enb_sofe(ptr);
- #endif                                /* USB_CFG_COMPLIANCE == USB_CFG_ENABLE */
+ #endif                                     /* USB_CFG_COMPLIANCE == USB_CFG_ENABLE */
 }
 
 /******************************************************************************
