@@ -13,7 +13,7 @@
  *  \defgroup pico_stdio_semihosting pico_stdio_semihosting
  *  \ingroup pico_stdio
  *
- *  Linking this library or calling `pico_enable_stdio_semihosting(TARGET)` in the CMake (which
+ *  Linking this library or calling `pico_enable_stdio_semihosting(TARGET ENABLED)` in the CMake (which
  *  achieves the same thing) will add semihosting to the drivers used for standard output
  */
 
@@ -35,6 +35,13 @@ extern stdio_driver_t stdio_semihosting;
  */
 void stdio_semihosting_init(void);
 
+/*! \brief Explicitly deinitialize stdout over semihosting and add it to the current set of stdout targets
+ *  \ingroup pico_stdio_semihosting
+ *
+ * \note this method is automatically called by \ref stdio_deinit_all() if `pico_stdio_semihosting` is included in the build
+ */
+void stdio_semihosting_deinit(void);
+
 #ifdef __cplusplus
 }
 #endif
